@@ -49,8 +49,7 @@ pub fn bundle_project(settings: &Settings, bundles: &[Bundle]) -> crate::Result<
       Arch::Universal => "universal",
       target => {
         return Err(crate::Error::ArchError(format!(
-          "Unsupported architecture: {:?}",
-          target
+          "Unsupported architecture: {target:?}"
         )));
       }
     }
@@ -59,7 +58,7 @@ pub fn bundle_project(settings: &Settings, bundles: &[Bundle]) -> crate::Result<
   let dmg_path = output_path.join(&dmg_name);
 
   let product_name = settings.product_name();
-  let bundle_file_name = format!("{}.app", product_name);
+  let bundle_file_name = format!("{product_name}.app");
   let bundle_dir = settings.project_out_directory().join("bundle/macos");
 
   let support_directory_path = output_path
@@ -69,10 +68,10 @@ pub fn bundle_project(settings: &Settings, bundles: &[Bundle]) -> crate::Result<
 
   for path in &[&support_directory_path, &output_path] {
     if path.exists() {
-      fs::remove_dir_all(path).with_context(|| format!("Failed to remove old {}", dmg_name))?;
+      fs::remove_dir_all(path).with_context(|| format!("Failed to remove old {dmg_name}"))?;
     }
     fs::create_dir_all(path)
-      .with_context(|| format!("Failed to create output directory at {:?}", path))?;
+      .with_context(|| format!("Failed to create output directory at {path:?}"))?;
   }
 
   // create paths for script
