@@ -8,7 +8,7 @@ use std::{
 };
 use ureq::ResponseExt;
 
-use crate::utils::http_utils::download;
+use crate::utils::http_utils::{base_ureq_agent, download};
 
 pub const WEBVIEW2_BOOTSTRAPPER_URL: &str = "https://go.microsoft.com/fwlink/p/?LinkId=2124703";
 pub const WEBVIEW2_OFFLINE_INSTALLER_X86_URL: &str =
@@ -23,10 +23,7 @@ pub const WIX_OUTPUT_FOLDER_NAME: &str = "msi";
 pub const WIX_UPDATER_OUTPUT_FOLDER_NAME: &str = "msi-updater";
 
 pub fn webview2_guid_path(url: &str) -> crate::Result<(String, String)> {
-  let agent: ureq::Agent = ureq::Agent::config_builder()
-    .proxy(ureq::Proxy::try_from_env())
-    .build()
-    .into();
+  let agent = base_ureq_agent();
   let response = agent.head(url).call().map_err(Box::new)?;
   let final_url = response.get_uri().to_string();
   let remaining_url = final_url.strip_prefix(WEBVIEW2_URL_PREFIX).ok_or_else(|| {
@@ -85,8 +82,7 @@ pub fn os_bitness<'a>() -> Option<&'a str> {
 }
 
 pub fn patch_binary(binary_path: &PathBuf, package_type: &crate::PackageType) -> crate::Result<()> {
-  let file_data = std::fs::read(binary_path)?;
-  let mut file_data = file_data; // make mutable
+  let mut file_data = std::fs::read(binary_path)?;
 
   let pe = match goblin::Object::parse(&file_data)? {
     goblin::Object::PE(pe) => pe,
@@ -104,17 +100,16 @@ pub fn patch_binary(binary_path: &PathBuf, package_type: &crate::PackageType) ->
     .ok_or(crate::Error::MissingBundleTypeVar)?;
 
   let data_offset = tauri_bundle_section.pointer_to_raw_data as usize;
-
-  if data_offset + 8 > file_data.len() {
-    return Err(crate::Error::BinaryOffsetOutOfRange);
-  }
-
-  let ptr_bytes = &file_data[data_offset..data_offset + 8];
-  let ptr_value = u64::from_le_bytes(ptr_bytes.try_into().map_err(|_| {
-    crate::Error::BinaryParseError(
-      std::io::Error::new(std::io::ErrorKind::InvalidData, "invalid pointer bytes").into(),
-    )
-  })?);
+  let pointer_size = if pe.is_64 { 8 } else { 4 };
+  let ptr_bytes = file_data
+    .get(data_offset..data_offset + pointer_size)
+    .ok_or(crate::Error::BinaryOffsetOutOfRange)?;
+  // `try_into` is safe to `unwrap` here because we have already checked the slice's size through `get`
+  let ptr_value = if pe.is_64 {
+    u64::from_le_bytes(ptr_bytes.try_into().unwrap())
+  } else {
+    u32::from_le_bytes(ptr_bytes.try_into().unwrap()).into()
+  };
 
   let rdata_section = pe
     .sections
@@ -132,15 +127,15 @@ pub fn patch_binary(binary_path: &PathBuf, package_type: &crate::PackageType) ->
     )
   })?;
 
+  // see "Relative virtual address (RVA)" for explanation of offset arithmetic here:
+  // https://learn.microsoft.com/en-us/windows/win32/debug/pe-format#general-concepts
   let file_offset = rdata_section.pointer_to_raw_data as usize
     + (rva as usize).saturating_sub(rdata_section.virtual_address as usize);
 
-  if file_offset + 3 > file_data.len() {
-    return Err(crate::Error::BinaryOffsetOutOfRange);
-  }
-
   // Overwrite the string at that offset
-  let string_bytes = &mut file_data[file_offset..file_offset + 3];
+  let string_bytes = file_data
+    .get_mut(file_offset..file_offset + 3)
+    .ok_or(crate::Error::BinaryOffsetOutOfRange)?;
   match package_type {
     crate::PackageType::Nsis => string_bytes.copy_from_slice(b"NSS"),
     crate::PackageType::WindowsMsi => string_bytes.copy_from_slice(b"MSI"),
