@@ -88,6 +88,11 @@ pub struct Options {
   /// e.g. `tauri ios build -- [runnerArgs]`.
   #[clap(last(true))]
   pub args: Vec<String>,
+  /// Do not error out if a version mismatch is detected on a Tauri package.
+  ///
+  /// Only use this when you are sure the mismatch is incorrectly detected as version mismatched Tauri packages can lead to unknown behavior.
+  #[clap(long)]
+  pub ignore_version_mismatches: bool,
 }
 
 #[derive(Debug, Clone, Copy, ValueEnum)]
@@ -97,6 +102,17 @@ pub enum ExportMethod {
   Debugging,
 }
 
+impl ExportMethod {
+  /// Xcode 15.4 deprecated these names (in this case we should use the Display impl).
+  pub fn pre_xcode_15_4_name(&self) -> String {
+    match self {
+      Self::AppStoreConnect => "app-store".to_string(),
+      Self::ReleaseTesting => "ad-hoc".to_string(),
+      Self::Debugging => "development".to_string(),
+    }
+  }
+}
+
 impl std::fmt::Display for ExportMethod {
   fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
     match self {
@@ -132,6 +148,8 @@ impl From<Options> for BuildOptions {
       config: options.config,
       args: options.args,
       ci: options.ci,
+      skip_stapling: false,
+      ignore_version_mismatches: options.ignore_version_mismatches,
     }
   }
 }
@@ -208,7 +226,27 @@ pub fn command(options: Options, noise_level: NoiseLevel) -> Result<()> {
 
   let mut export_options_plist = plist::Dictionary::new();
   if let Some(method) = options.export_method {
-    export_options_plist.insert("method".to_string(), method.to_string().into());
+    let xcode_version =
+      crate::info::env_system::xcode_version().context("failed to determine Xcode version")?;
+    let mut iter = xcode_version.split('.');
+    let major = iter.next().context(format!(
+      "failed to parse Xcode version `{xcode_version}` as semver"
+    ))?;
+    let minor = iter.next().context(format!(
+      "failed to parse Xcode version `{xcode_version}` as semver"
+    ))?;
+    let major = major.parse::<u64>().context(format!(
+      "failed to parse Xcode version `{xcode_version}` as semver: major is not a number"
+    ))?;
+    let minor = minor.parse::<u64>().context(format!(
+      "failed to parse Xcode version `{xcode_version}` as semver: minor is not a number"
+    ))?;
+
+    if major < 15 || (major == 15 && minor < 4) {
+      export_options_plist.insert("method".to_string(), method.pre_xcode_15_4_name().into());
+    } else {
+      export_options_plist.insert("method".to_string(), method.to_string().into());
+    }
   }
 
   let (keychain, provisioning_profile) = super::signing_from_env()?;
