@@ -389,7 +389,7 @@ fn detect_target_ok<'a>(env: &Env) -> Option<&'a Target<'a>> {
 fn open_and_wait(config: &AppleConfig, env: &Env) -> ! {
   log::info!("Opening Xcode");
   if let Err(e) = os::open_file_with("Xcode", config.project_dir(), env) {
-    log::error!("{}", e);
+    log::error!("{e}");
   }
   loop {
     sleep(Duration::from_secs(24 * 60 * 60));
