@@ -2,15 +2,12 @@
 // SPDX-License-Identifier: Apache-2.0
 // SPDX-License-Identifier: MIT
 
-use super::PhysicalRect;
 use gtk::prelude::MonitorExt;
-use tao::{
-  dpi::{PhysicalPosition, PhysicalSize},
-  platform::unix::MonitorHandleExtUnix,
-};
+use tao::platform::unix::MonitorHandleExtUnix;
+use tauri_runtime::dpi::{PhysicalPosition, PhysicalRect, PhysicalSize};
 
 impl super::MonitorExt for tao::monitor::MonitorHandle {
-  fn work_area(&self) -> PhysicalRect {
+  fn work_area(&self) -> PhysicalRect<i32, u32> {
     let rect = self.gdk_monitor().workarea();
     PhysicalRect {
       size: PhysicalSize::new(rect.width() as u32, rect.height() as u32),
