@@ -4,6 +4,8 @@
 
 //! A layer between raw [`Runtime`] webviews and Tauri.
 //!
+#[cfg(not(any(target_os = "android", target_os = "ios")))]
+use crate::window::WindowId;
 use crate::{window::is_label_valid, Rect, Runtime, UserEvent};
 
 use http::Request;
@@ -30,8 +32,12 @@ type WebResourceRequestHandler =
 
 type NavigationHandler = dyn Fn(&Url) -> bool + Send;
 
+type NewWindowHandler = dyn Fn(Url, NewWindowFeatures) -> NewWindowResponse + Send + Sync;
+
 type OnPageLoadHandler = dyn Fn(Url, PageLoadEvent) + Send;
 
+type DocumentTitleChangedHandler = dyn Fn(String) + Send + 'static;
+
 type DownloadHandler = dyn Fn(DownloadEvent) -> bool + Send + Sync;
 
 #[cfg(target_os = "ios")]
@@ -78,6 +84,92 @@ pub enum PageLoadEvent {
   Finished,
 }
 
+/// Information about the webview that initiated a new window request.
+#[derive(Debug)]
+pub struct NewWindowOpener {
+  /// The instance of the webview that initiated the new window request.
+  ///
+  /// This must be set as the related view of the new webview. See [`WebviewAttributes::related_view`].
+  #[cfg(any(
+    target_os = "linux",
+    target_os = "dragonfly",
+    target_os = "freebsd",
+    target_os = "netbsd",
+    target_os = "openbsd",
+  ))]
+  pub webview: webkit2gtk::WebView,
+  /// The instance of the webview that initiated the new window request.
+  ///
+  /// The target webview environment **MUST** match the environment of the opener webview. See [`WebviewAttributes::environment`].
+  #[cfg(windows)]
+  pub webview: webview2_com::Microsoft::Web::WebView2::Win32::ICoreWebView2,
+  #[cfg(windows)]
+  pub environment: webview2_com::Microsoft::Web::WebView2::Win32::ICoreWebView2Environment,
+  /// The instance of the webview that initiated the new window request.
+  #[cfg(target_os = "macos")]
+  pub webview: objc2::rc::Retained<objc2_web_kit::WKWebView>,
+  /// Configuration of the target webview.
+  ///
+  /// This **MUST** be used when creating the target webview. See [`WebviewAttributes::webview_configuration`].
+  #[cfg(target_os = "macos")]
+  pub target_configuration: objc2::rc::Retained<objc2_web_kit::WKWebViewConfiguration>,
+}
+
+/// Window features of a window requested to open.
+#[derive(Debug)]
+pub struct NewWindowFeatures {
+  pub(crate) size: Option<crate::dpi::LogicalSize<f64>>,
+  pub(crate) position: Option<crate::dpi::LogicalPosition<f64>>,
+  pub(crate) opener: NewWindowOpener,
+}
+
+impl NewWindowFeatures {
+  pub fn new(
+    size: Option<crate::dpi::LogicalSize<f64>>,
+    position: Option<crate::dpi::LogicalPosition<f64>>,
+    opener: NewWindowOpener,
+  ) -> Self {
+    Self {
+      size,
+      position,
+      opener,
+    }
+  }
+
+  /// Specifies the size of the content area
+  /// as defined by the user's operating system where the new window will be generated.
+  pub fn size(&self) -> Option<crate::dpi::LogicalSize<f64>> {
+    self.size
+  }
+
+  /// Specifies the position of the window relative to the work area
+  /// as defined by the user's operating system where the new window will be generated.
+  pub fn position(&self) -> Option<crate::dpi::LogicalPosition<f64>> {
+    self.position
+  }
+
+  /// Returns information about the webview that initiated a new window request.
+  pub fn opener(&self) -> &NewWindowOpener {
+    &self.opener
+  }
+}
+
+/// Response for the new window request handler.
+pub enum NewWindowResponse {
+  /// Allow the window to be opened with the default implementation.
+  Allow,
+  /// Allow the window to be opened, with the given window.
+  ///
+  /// ## Platform-specific:
+  ///
+  /// **Linux**: The webview must be related to the caller webview. See [`WebviewAttributes::related_view`].
+  /// **Windows**: The webview must use the same environment as the caller webview. See [`WebviewAttributes::environment`].
+  #[cfg(not(any(target_os = "android", target_os = "ios")))]
+  Create { window_id: WindowId },
+  /// Deny the window from being opened.
+  Deny,
+}
+
 /// A webview that has yet to be built.
 pub struct PendingWebview<T: UserEvent, R: Runtime<T>> {
   /// The label that the webview will be named.
@@ -94,6 +186,10 @@ pub struct PendingWebview<T: UserEvent, R: Runtime<T>> {
   /// A handler to decide if incoming url is allowed to navigate.
   pub navigation_handler: Option<Box<NavigationHandler>>,
 
+  pub new_window_handler: Option<Box<NewWindowHandler>>,
+
+  pub document_title_changed_handler: Option<Box<DocumentTitleChangedHandler>>,
+
   /// The resolved URL to load on the webview.
   pub url: String,
 
@@ -125,6 +221,8 @@ impl<T: UserEvent, R: Runtime<T>> PendingWebview<T, R> {
         label,
         ipc_handler: None,
         navigation_handler: None,
+        new_window_handler: None,
+        document_title_changed_handler: None,
         url: "tauri://localhost".to_string(),
         #[cfg(target_os = "android")]
         on_webview_created: None,
@@ -255,8 +353,30 @@ pub struct WebviewAttributes {
   /// This relies on [`objc2_ui_kit`] which does not provide a stable API yet, so it can receive breaking changes in minor releases.
   #[cfg(target_os = "ios")]
   pub input_accessory_view_builder: Option<InputAccessoryViewBuilder>,
+
+  /// Set the environment for the webview.
+  /// Useful if you need to share the same environment, for instance when using the [`PendingWebview::new_window_handler`].
+  #[cfg(windows)]
+  pub environment: Option<webview2_com::Microsoft::Web::WebView2::Win32::ICoreWebView2Environment>,
+
+  /// Creates a new webview sharing the same web process with the provided webview.
+  /// Useful if you need to link a webview to another, for instance when using the [`PendingWebview::new_window_handler`].
+  #[cfg(any(
+    target_os = "linux",
+    target_os = "dragonfly",
+    target_os = "freebsd",
+    target_os = "netbsd",
+    target_os = "openbsd",
+  ))]
+  pub related_view: Option<webkit2gtk::WebView>,
+
+  #[cfg(target_os = "macos")]
+  pub webview_configuration: Option<objc2::rc::Retained<objc2_web_kit::WKWebViewConfiguration>>,
 }
 
+unsafe impl Send for WebviewAttributes {}
+unsafe impl Sync for WebviewAttributes {}
+
 #[cfg(target_os = "ios")]
 #[non_exhaustive]
 pub struct InputAccessoryViewBuilder(pub Box<InputAccessoryViewBuilderFn>);
@@ -360,6 +480,18 @@ impl WebviewAttributes {
       allow_link_preview: true,
       #[cfg(target_os = "ios")]
       input_accessory_view_builder: None,
+      #[cfg(windows)]
+      environment: None,
+      #[cfg(any(
+        target_os = "linux",
+        target_os = "dragonfly",
+        target_os = "freebsd",
+        target_os = "netbsd",
+        target_os = "openbsd",
+      ))]
+      related_view: None,
+      #[cfg(target_os = "macos")]
+      webview_configuration: None,
     }
   }
 
