@@ -14,6 +14,7 @@ use crate::{
   event::EventTarget,
   ipc::ScopeObject,
   runtime::dpi::{PhysicalPosition, PhysicalSize},
+  webview::NewWindowResponse,
   window::Monitor,
   Emitter, EventName, Listener, ResourceTable, Window,
 };
@@ -27,6 +28,7 @@ use crate::{
     UserAttentionType,
   },
 };
+use tauri_runtime::webview::NewWindowFeatures;
 use tauri_utils::config::{BackgroundThrottlingPolicy, Color, WebviewUrl, WindowConfig};
 use url::Url;
 
@@ -34,7 +36,7 @@ use crate::{
   ipc::{CommandArg, CommandItem, InvokeError, OwnedInvokeResponder},
   manager::AppManager,
   sealed::{ManagerBase, RuntimeOrDispatch},
-  webview::{Cookie, PageLoadPayload, WebviewBuilder},
+  webview::{Cookie, PageLoadPayload, WebviewBuilder, WebviewEvent},
   window::WindowBuilder,
   AppHandle, Event, EventId, Manager, Runtime, Webview, WindowEvent,
 };
@@ -270,6 +272,82 @@ impl<'a, R: Runtime, M: Manager<R>> WebviewWindowBuilder<'a, R, M> {
     self
   }
 
+  /// Set a new window request handler to decide if incoming url is allowed to be opened.
+  ///
+  /// A new window is requested to be opened by the [window.open] API.
+  ///
+  /// The closure take the URL to open and the window features object and returns [`NewWindowResponse`] to determine whether the window should open.
+  ///
+  /// # Examples
+  /// ```rust,no_run
+  /// use tauri::{
+  ///   utils::config::WebviewUrl,
+  ///   webview::WebviewWindowBuilder,
+  /// };
+  /// use http::header::HeaderValue;
+  /// use std::collections::HashMap;
+  /// tauri::Builder::default()
+  ///   .setup(|app| {
+  ///     let app_ = app.handle().clone();
+  ///     let webview_window = WebviewWindowBuilder::new(app, "core", WebviewUrl::App("index.html".into()))
+  ///       .on_new_window(move |url, features| {
+  ///         let builder = tauri::WebviewWindowBuilder::new(
+  ///           &app_,
+  ///           // note: add an ID counter or random label generator to support multiple opened windows at the same time
+  ///           "opened-window",
+  ///           tauri::WebviewUrl::External("about:blank".parse().unwrap()),
+  ///         )
+  ///         .window_features(features)
+  ///         .on_document_title_changed(|window, title| {
+  ///           window.set_title(&title).unwrap();
+  ///         })
+  ///         .title(url.as_str());
+  ///
+  ///         let window = builder.build().unwrap();
+  ///         tauri::webview::NewWindowResponse::Create { window }
+  ///       })
+  ///       .build()?;
+  ///     Ok(())
+  ///   });
+  /// ```
+  ///
+  /// # Platform-specific
+  ///
+  /// - **Android / iOS**: Not supported.
+  /// - **Windows**: The closure is executed on a separate thread to prevent a deadlock.
+  ///
+  /// [window.open]: https://developer.mozilla.org/en-US/docs/Web/API/Window/open
+  pub fn on_new_window<
+    F: Fn(Url, NewWindowFeatures) -> NewWindowResponse<R> + Send + Sync + 'static,
+  >(
+    mut self,
+    f: F,
+  ) -> Self {
+    self.webview_builder = self.webview_builder.on_new_window(f);
+    self
+  }
+
+  /// Defines a closure to be executed when the document title changes.
+  ///
+  /// Note that it may run before or after the navigation event.
+  pub fn on_document_title_changed<F: Fn(WebviewWindow<R>, String) + Send + 'static>(
+    mut self,
+    f: F,
+  ) -> Self {
+    self.webview_builder = self
+      .webview_builder
+      .on_document_title_changed(move |webview, url| {
+        f(
+          WebviewWindow {
+            window: webview.window(),
+            webview,
+          },
+          url,
+        )
+      });
+    self
+  }
+
   /// Set a download event handler to be notified when a download is requested or finished.
   ///
   /// Returning `false` prevents the download from happening on a [`DownloadEvent::Requested`] event.
@@ -524,6 +602,13 @@ impl<'a, R: Runtime, M: Manager<R>> WebviewWindowBuilder<'a, R, M> {
     self
   }
 
+  /// Whether the window will be focusable or not.
+  #[must_use]
+  pub fn focusable(mut self, focusable: bool) -> Self {
+    self.window_builder = self.window_builder.focusable(focusable);
+    self
+  }
+
   /// Whether the window will be initially focused or not.
   #[must_use]
   pub fn focused(mut self, focused: bool) -> Self {
@@ -1177,6 +1262,99 @@ impl<R: Runtime, M: Manager<R>> WebviewWindowBuilder<'_, R, M> {
       .with_input_accessory_view_builder(builder);
     self
   }
+
+  /// Set the environment for the webview.
+  /// Useful if you need to share the same environment, for instance when using the [`Self::on_new_window`].
+  #[cfg(all(feature = "wry", windows))]
+  pub fn with_environment(
+    mut self,
+    environment: webview2_com::Microsoft::Web::WebView2::Win32::ICoreWebView2Environment,
+  ) -> Self {
+    self.webview_builder = self.webview_builder.with_environment(environment);
+    self
+  }
+
+  /// Creates a new webview sharing the same web process with the provided webview.
+  /// Useful if you need to link a webview to another, for instance when using the [`Self::on_new_window`].
+  #[cfg(all(
+    feature = "wry",
+    any(
+      target_os = "linux",
+      target_os = "dragonfly",
+      target_os = "freebsd",
+      target_os = "netbsd",
+      target_os = "openbsd",
+    )
+  ))]
+  pub fn with_related_view(mut self, related_view: webkit2gtk::WebView) -> Self {
+    self.webview_builder = self.webview_builder.with_related_view(related_view);
+    self
+  }
+
+  /// Set the webview configuration.
+  /// Useful if you need to share the same webview configuration, for instance when using the [`Self::on_new_window`].
+  #[cfg(target_os = "macos")]
+  pub fn with_webview_configuration(
+    mut self,
+    webview_configuration: objc2::rc::Retained<objc2_web_kit::WKWebViewConfiguration>,
+  ) -> Self {
+    self.webview_builder = self
+      .webview_builder
+      .with_webview_configuration(webview_configuration);
+    self
+  }
+
+  /// Set the window features.
+  /// Useful if you need to share the same window features, for instance when using the [`Self::on_new_window`].
+  #[cfg(any(
+    target_os = "macos",
+    windows,
+    target_os = "linux",
+    target_os = "dragonfly",
+    target_os = "freebsd",
+    target_os = "netbsd",
+    target_os = "openbsd"
+  ))]
+  pub fn window_features(mut self, features: NewWindowFeatures) -> Self {
+    if let Some(position) = features.position() {
+      self.window_builder = self.window_builder.position(position.x, position.y);
+    }
+
+    if let Some(size) = features.size() {
+      self.window_builder = self.window_builder.inner_size(size.width, size.height);
+    }
+
+    #[cfg(target_os = "macos")]
+    {
+      self.webview_builder = self
+        .webview_builder
+        .with_webview_configuration(features.opener().target_configuration.clone());
+    }
+
+    #[cfg(all(feature = "wry", windows))]
+    {
+      self.webview_builder = self
+        .webview_builder
+        .with_environment(features.opener().environment.clone());
+    }
+
+    #[cfg(all(
+      feature = "wry",
+      any(
+        target_os = "linux",
+        target_os = "dragonfly",
+        target_os = "freebsd",
+        target_os = "netbsd",
+        target_os = "openbsd",
+      )
+    ))]
+    {
+      self.webview_builder = self
+        .webview_builder
+        .with_related_view(features.opener().webview.clone());
+    }
+    self
+  }
 }
 
 /// A type that wraps a [`Window`] together with a [`Webview`].
@@ -1204,7 +1382,7 @@ impl<R: Runtime> Clone for WebviewWindow<R> {
 
 impl<R: Runtime> Eq for WebviewWindow<R> {}
 impl<R: Runtime> PartialEq for WebviewWindow<R> {
-  /// Only use the [`Window`]'s label to compare equality.
+  /// Only use the [`Webview`]'s label to compare equality.
   fn eq(&self, other: &Self) -> bool {
     self.webview.eq(&other.webview)
   }
@@ -1269,6 +1447,11 @@ impl<R: Runtime> WebviewWindow<R> {
     self.window.on_window_event(f);
   }
 
+  /// Registers a webview event listener.
+  pub fn on_webview_event<F: Fn(&WebviewEvent) + Send + 'static>(&self, f: F) {
+    self.webview.on_webview_event(f);
+  }
+
   /// Resolves the given command scope for this webview on the currently loaded URL.
   ///
   /// If the command is not allowed, returns None.
@@ -1860,6 +2043,16 @@ impl<R: Runtime> WebviewWindow<R> {
     self.window.set_focus()
   }
 
+  /// Sets whether the window can be focused.
+  ///
+  /// ## Platform-specific
+  ///
+  /// - **macOS**: If the window is already focused, it is not possible to unfocus it after calling `set_focusable(false)`.
+  ///   In this case, you might consider calling [`Window::set_focus`] but it will move the window to the back i.e. at the bottom in terms of z-order.
+  pub fn set_focusable(&self, focusable: bool) -> crate::Result<()> {
+    self.window.set_focusable(focusable)
+  }
+
   /// Sets this window' icon.
   pub fn set_icon(&self, icon: Image<'_>) -> crate::Result<()> {
     self.window.set_icon(icon)
@@ -2211,15 +2404,11 @@ impl<R: Runtime> WebviewWindow<R> {
   ///
   /// # Stability
   ///
-  /// The return value of this function leverages [`tauri_runtime::Cookie`] which re-exports the cookie crate.
-  /// This dependency might receive updates in minor Tauri releases.
+  /// See [Self::cookies].
   ///
   /// # Known issues
   ///
-  /// On Windows, this function deadlocks when used in a synchronous command or event handlers, see [the Webview2 issue].
-  /// You should use `async` commands and separate threads when reading cookies.
-  ///
-  /// [the Webview2 issue]: https://github.com/tauri-apps/wry/issues/583
+  /// See [Self::cookies].
   pub fn cookies_for_url(&self, url: Url) -> crate::Result<Vec<Cookie<'static>>> {
     self.webview.cookies_for_url(url)
   }
@@ -2248,6 +2437,24 @@ impl<R: Runtime> WebviewWindow<R> {
   pub fn cookies(&self) -> crate::Result<Vec<Cookie<'static>>> {
     self.webview.cookies()
   }
+
+  /// Set a cookie for the webview.
+  ///
+  /// # Stability
+  ///
+  /// See [Self::cookies].
+  pub fn set_cookie(&self, cookie: Cookie<'_>) -> crate::Result<()> {
+    self.webview.set_cookie(cookie)
+  }
+
+  /// Delete a cookie for the webview.
+  ///
+  /// # Stability
+  ///
+  /// See [Self::cookies].
+  pub fn delete_cookie(&self, cookie: Cookie<'_>) -> crate::Result<()> {
+    self.webview.delete_cookie(cookie)
+  }
 }
 
 impl<R: Runtime> Listener<R> for WebviewWindow<R> {
